# QGrain

QGrain is an easy to use software that can unmix the multi-modal grain size distribution to some single modals.

It's written by Python. This makes it can benefit from the great open source and scientific computation communities.

QGrain is still during the rapid development stage, its functionalities and usages may changes many and many times. And of course, there probably are some bugs. We are very sorry for its immaturity.

We are really hope to receive your feedbacks. Whatever it's bug report, request of new feature, disscusion on algorithms.

Moreover, we are looking forward that there are some partners to join the development of QGrain.

If you have any idea, you can contact the authors below.

## Authors

* Yuming Liu

  <a href="mailto:\\liuyuming@ieecas.cn">liuyuming@ieecas.cn</a>
